// System includes
#include <QImage>
#include <QPainter>
#include <QtTest/QtTest>

// User includes
#include "model.h"

// Constants

// ======== LOCAL FUNCTIONS ========

// ======== MEMBER FUNCTIONS ========

/*!
    C++ Constructor
*/
TestModel::TestModel(QObject *parent)
    : QAbstractListModel(parent),
      QDeclarativeImageProvider(QDeclarativeImageProvider::Image),
      m_updateIndex(-1),
      m_runningNumber(0)
{
    // Construct array of roles, from which button data is collected
    QHash<int, QByteArray> roles;
    roles[Icon] = "icon1";
    roles[Text1] = "name1";
    roles[Text2] = "name2";
    setRoleNames(roles);

    startTimer(1);

    return;
}

/*!
    Return item count
*/
int TestModel::rowCount(const QModelIndex &) const
{
    return count();
}

/*!
    Return item count
*/
int TestModel::count() const
{
    return 1000;
}

/*!
    Return selected data for the given index
*/
QVariant TestModel::data(const QModelIndex &index, int role) const
{
    QVariant ret;
    const int i = index.row();

    // Fill-in the requested data
    switch (role) {
        case Icon: {
                QString name = "image://images/" + QString().setNum(i) + "/" + QString().setNum(m_runningNumber);
                ret = name;
            } break;
        case Text1: {
                QString name = "Test " + QString().setNum(i);
                if (m_updateIndex >= 0) {
                    name += "u";
                }
                ret = name;
            } break;
        case Text2: {
                QString name = QString().setNum(i % 1000);
                ret = name;
                for (int i = 0; i < 10000; i++);
            } break;
        default: {
            } break;
    }

    return ret;
}

/*!
    Return thumbnail
*/
QImage TestModel::requestImage(const QString &id, QSize *, const QSize &)
{
    QImage image(200, 200, QImage::Format_ARGB32);
    image.fill(Qt::transparent);
    bool ok;
    QStringList list = id.split("/");
    if (list.count()) {
        const int i = list.at(0).toInt(&ok);
        if (ok) {
            QPainter painter(&image);
            painter.fillRect(image.rect(), Qt::Dense5Pattern);
            painter.setPen(QColor(Qt::yellow));
            QFont font("Nokia Standard Regular", 50);
            painter.setFont(font);
            QString name = QString().setNum(i);
            if (m_updateIndex >= 0) {
                name += "u";
            }
            painter.drawText(50, 125, name);
        }
    }

    return image;
}

/*!
    Not supported
*/
QPixmap TestModel::requestPixmap(const QString &, QSize *, const QSize &)
{
    return QPixmap();
}

/*!
      Update model contents periodicly
 */
void TestModel::timerEvent(QTimerEvent *event)
{
    if (event) {
        if (++m_updateIndex < count()) {
            const QModelIndex i = index(m_updateIndex);
            dataChanged(i, i);
            m_runningNumber++;
            QVariant var = data(i, Icon);
            QString updatedIcon = var.toString();
            emit refreshItem(m_updateIndex, updatedIcon);
        } else {
            killTimer(event->timerId());
        }
    }

    return;
}

/*!
    -
*/
void TestModel::heap()
{
#ifdef Q_OS_SYMBIAN
    RHeap &heap = User::Heap();
    TInt totalAllocSize;
    TInt biggestBlock;
    TInt cellCount = heap.AllocSize(totalAllocSize);
    TInt freeSpace = heap.Available(biggestBlock);
    qDebug() << "cellCount:" << static_cast<int>(cellCount) << ", totalAllocSize:" << static_cast<int>(totalAllocSize);
#endif

    return;
}

// End of File

