#ifndef MODEL_H
#define MODEL_H

// System includes
#include <QtCore>
#include <QAbstractListModel>
#include <QDeclarativeImageProvider>

// User includes

// Forward declarations

/*!
@ListTest
\class TestModel
\brief

-
*/
class TestModel
    : public QAbstractListModel,
      public QDeclarativeImageProvider
{
    Q_OBJECT

public:
    enum ItemRoles {
        Icon = Qt::UserRole + 1,
        Text1,
        Text2
    };

public: // Constructors
    /*!
     * C++ Constructor
     * \param parent
     */
    TestModel(QObject *parent = NULL);

public: // From QAbstractListModel
    /*!
     * Return item count
     * \param parent
     * \return int, 0..n
     */
    int rowCount(const QModelIndex &parent = QModelIndex()) const;

    /*!
     * Fetch button data
     * \param index
     * \param role
     */
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;

public: // New methods
    /*!
    * Return item count
    * \return int, 0..n
    */
    Q_INVOKABLE int count() const;

    /*!
    * Check heap
    */
    Q_INVOKABLE void heap();

public: // From QDeclarativeImageProvider
    QImage requestImage(const QString &id, QSize *size, const QSize &requestedSize);
    QPixmap requestPixmap(const QString &id, QSize *size, const QSize &requestedSize);

signals:
    void refreshItem(const int updatedIndex, const QString updatedIcon);

private:
    /*!
     * Update model contents periodicly
     * \param event Timer event
     */
    void timerEvent(QTimerEvent *event);

private: // Data
    int m_updateIndex;
    int m_runningNumber;
};

#endif // MODEL_H

// End Of File



