import Qt 4.7

Item {
     id: button
     clip: true

     property int layoutDirection: 0
     property bool focusable: true
     property int buttonId
     property bool enabled: true
     property int repeatInterval: 0
     property bool highlighted: false
     property bool isDown: false
     property bool isLongPressDown: false

     property string suffix: ".svg"
     property string background: "qtg_fr_pushbutton"
     property string backgroundPressed
     property string backgroundNormal
     property string backgroundHighlighted
     property string backgroundDisabled
     property bool feedback: true
     property bool feedbackEmitted: false

     // Button signals
     signal clicked
     signal pressed
     signal released
     signal longPressStarted
     signal longPressStopped

     onHighlightedChanged: {
         polish()
     }

     function polish() {
         if (highlighted) {
             var fg = parent
             while (typeof fg.focusGroup != "undefined") {
                 fg = fg.focusGroup
             }
             if (typeof fg.focusItem != "undefined") {
                 if (fg.focusItem && (fg.focusItem != button)) {
                     fg.focusItem.focus = false
                     fg.focusItem.highlighted = false
                 }
                 fg.focusItem = button
                 button.focus = true
             }
         }
     }

     onFocusChanged: {
         highlighted = focus
     }

     onEnabledChanged: {
         polish();
     }

     Keys.onPressed: {
         if (event.accepted == false) {
             if (enabled && (event.key == Qt.Key_Return || event.key == Qt.Key_Enter || event.key == Qt.Key_Select)) {
                 event.accepted = true
                 isDown = true
                 pressed()
             }
         }
     }

     Keys.onReleased: {
         if (event.accepted == false) {
             if (enabled && (event.key == Qt.Key_Return || event.key == Qt.Key_Enter || event.key == Qt.Key_Select)) {
                 event.accepted = true
                 isDown = false
                 clicked()
                 released()
             }
         }
     }

     function repeatEvent() {
         button.clicked()
     }

     Timer {
         id: repeatTimer
         interval: button.repeatInterval
         running: false
         repeat: true
         onTriggered: button.repeatEvent()
     }

     MouseArea {
        id: toucharea
        anchors.fill: parent
        z: 1
        onCanceled: {
            if (repeatTimer.running == true) {
                repeatTimer.running = false
            }
            isDown = false
            polish()
        }
        onExited:  {
            if (repeatTimer.running == true) {
                repeatTimer.running = false
            }
            isDown = false;
            polish()
        }
        onClicked: {
            if (button.enabled) {
                button.clicked()
            }
        }
        onPressed: {
            if (button.enabled) {
                isDown = true
                if (focusable) {
                    highlighted = true
                }
                button.pressed()
                polish()
            }
        }
        onReleased: {
            if (button.enabled) {
                if (repeatTimer.running == true) {
                    repeatTimer.running = false
                }
                if (button.isLongPressDown == true) {
                    button.isLongPressDown = false
                    button.longPressStopped()
                }
                isDown = false
                button.released()
                polish()
            }
        }
        onPressAndHold: {
            if (button.enabled) {
                if (button.enabled && button.repeatInterval > 0) {
                    button.repeatEvent()
                    repeatTimer.running = true
                }

                button.isLongPressDown = true
                button.longPressStarted()
            }
        }
    }

    // Button background
    CustomBackground {
        id: background
        anchors.fill: parent
        background: button.backgroundNormal ? button.backgroundNormal : button.background + "_normal" + suffix

        states: [
            State {
                name: "highlighted"
                when: enabled && highlighted && focusable
                PropertyChanges {
                    target: background
                    background: button.backgroundHighlighted ? button.backgroundHighlighted : button.background + "_highlighted" + suffix
                }
            },
            State {
                name: "disabled"
                when: !enabled
                PropertyChanges {
                    target: background
                    background: button.backgroundDisabled ? button.backgroundDisabled : button.background + "_disabled" + suffix
                }
            },
            State {
                name: "pressed"
                when: isDown && enabled
                PropertyChanges {
                    target: background
                    background: button.backgroundPressed ? button.backgroundPressed : button.background + "_pressed" + suffix
                }
            }
        ]
    }

    states: [
        State {
            name: "Current"
            when: listButton.ListView.isCurrentItem
            PropertyChanges {
                target: listButton
                highlighted: true
            }
        }
    ]

    Connections {
        target: button
        onPressed: {
            if (button.feedback) {
                feedbackEmitted = false
                audibleFeedback.pressed()
            }
        }
        onReleased: {
            if (button.feedback) {
                feedbackEmitted = false
                audibleFeedback.released()
            }
        }
        onClicked: {
            if (button.feedback && !feedbackEmitted) {
                feedbackEmitted = true
                audibleFeedback.clicked()
            }
        }
    }
}

// End Of File



