import Qt 4.7

ButtonBase {
    id: listButton
    width: 360
    height: 150

    property string icon
    property alias text1: text1.text
    property alias text2: text2.text
    property int textHeight1: 31
    property int lineCount1: 1
    property int textHeight2: 26
    property alias wrap1: text1.wrapMode
    property alias wrap2: text2.wrapMode
    property alias elide1: text1.elide
    property alias elide2: text2.elide
    property string badge
    property string badgeBackground
    property string badgeText
    property int badgeSize
    property int badgeBackgroundSize
    property int badgeTextHeight
    property int iconMarginLeftRight: 15
    property alias iconWidth: iconItem.width
    property alias iconHeight: iconItem.height
    property variant orientation: height > width ? ListView.Vertical : ListView.Horizontal
    property string feedback

    onEnabledChanged: {
        var opacity = enabled ? 1 : 0.4
        iconItem.opacity = opacity
        text1.opacity = opacity
        text2.opacity = opacity
    }

    Item {
        id: layout
        anchors.fill: parent
        anchors.rightMargin: 15
        anchors.topMargin: 5
        anchors.leftMargin: iconMarginLeftRight
        anchors.bottomMargin: 5

        Text {
            id: text1
            x: iconItem.width + iconMarginLeftRight
            width: layout.width - x
            height: layout.height
            color: "#ffffff"
            wrapMode: Text.NoWrap
            elide: Text.ElideRight
            style: Text.Normal
            font.bold: false
            font.pixelSize: textHeight1
            verticalAlignment: Text.AlignVCenter
            property int lineHeight: font.pixelSize * 1.25
            property int lineCount: paintedHeight / lineHeight
            property int calculatedHeight: lineCount * lineHeight
            property int effectiveHeight: calculatedHeight > height ? height: calculatedHeight

        }

        Text {
            id: text2
            color: "#eeeeee"
            wrapMode: Text.WrapAnywhere
            elide: Text.ElideNone
            style: Text.Normal
            font.bold: false
            font.pixelSize: textHeight2
            property int lineHeight: font.pixelSize * 1.25
            property int lineCount: paintedHeight / lineHeight
            property int calculatedHeight: lineCount * lineHeight
            property int effectiveHeight: calculatedHeight > height ? height: calculatedHeight

            states: [
                State {
                    name: "two_lines"
                    when: text2.text != ""

                    PropertyChanges {
                        target: text1
                        y: (layout.height - 5 - text1.effectiveHeight - text2.height) / 2
                        height: (lineCount1 * lineHeight) - 3
                        verticalAlignment: Text.AlignTop
                        clip: true
                    }

                    PropertyChanges {
                        target: text2
                        x: text1.x
                        y: text1.y + text1.effectiveHeight + 5
                        width: text1.width
                        height: lineHeight
                        verticalAlignment: Text.AlignTop
                    }
                }
            ]
        }

        Image {
            id: iconItem
            anchors.verticalCenter: layout.verticalCenter
            width: 130
            height: 130
            sourceSize.width: width
            sourceSize.height: height
            source: listButton.icon
            asynchronous: false

            Repeater {
                id: repeater
                model: (listButton.badge || listButton.badgeBackground) ? 1 : 0
                BadgeItem {
                    id: badgeIcon
                    anchors.top: parent.top
                    anchors.left: parent.left
                    width: listButton.badgeBackgroundSize
                    height: listButton.badgeBackgroundSize
                    textHeight: listButton.badgeTextHeight
                    badgeWidth: listButton.badgeSize
                    badgeHeight: listButton.badgeSize
                    icon: listButton.badge
                    background: listButton.badgeBackground
                    text: listButton.badgeText
                    enabled: listButton.enabled

                    states: [
                        State {
                            name: "mirrored"
                            when: repeater.model == 1 && layoutDirection == Qt.RightToLeft

                            AnchorChanges {
                                target: badgeIcon
                                anchors.left: undefined
                                anchors.right: parent.right
                            }
                        }
                    ]
                }
            }
        }

        states: [
            State {
                name: "landscape"
                when: orientation == ListView.Vertical

                PropertyChanges {
                    target: layout
                    anchors.leftMargin: 5
                    anchors.rightMargin: 5
                }

                AnchorChanges {
                    target: iconItem
                    anchors.verticalCenter: undefined
                }

                PropertyChanges {
                    target: iconItem
                    x: (layout.width - width) / 2
                    y: (layout.height - height - text1.height - 15) / 2
                }

                PropertyChanges {
                    target: text1
                    x: 0
                    y: iconItem.y + iconItem.height + 15
                    height: font.pixelSize * 1.25
                    horizontalAlignment: Text.AlignHCenter
                    elide: Text.ElideNone
                    verticalAlignment: Text.AlignTop
                }

                PropertyChanges {
                    target: text2
                    x: 0
                    y: text1.y + text1.height + 5
                    horizontalAlignment: Text.AlignHCenter
                    elide: Text.ElideNone
                    verticalAlignment: Text.AlignTop
                }
            },
            State {
                name: "portrait_mirrored"
                when: orientation == ListView.Horizontal && layoutDirection == Qt.RightToLeft && (text1.text != "" || text2.text != "")

                PropertyChanges {
                    target: iconItem
                    x: layout.width - width
                }

                PropertyChanges {
                    target: text1
                    x: 0
                    width: layout.width - iconItem.width - iconMarginLeftRight
                }

                PropertyChanges {
                    target: text2
                    x: 0
                    width: text1.width
                }

                PropertyChanges {
                    target: layout
                    anchors.leftMargin: 15
                    anchors.rightMargin: iconMarginLeftRight
                }
            },
            State {
                name: "icon_only"
                when: text1.text == "" && text2.text == ""

                PropertyChanges {
                    target: iconItem
                    x: (layout.width - width) / 2
                    y: (layout.height - height) / 2
                }

                PropertyChanges {
                    target: text1
                    visible: false
                }

                PropertyChanges {
                    target: text2
                    visible: false
                }
            }
        ]
    }
}

// End Of File



